
ent_mer_reg="/ssproxy/entMerReg"
indv_mer_reg="/ssproxy/indvMerReg"
mer_modify="/ssproxy/merModify"
query_merch_info="/ssproxy/queryMerchInfo"
add_chains_corp_info="/ssproxy/addChainsCorpInfo"
modify_chains_corp_info="/ssproxy/modifyChainsCorpInfo"
bind_chains_mer="/ssproxy/bindChainsMer"
query_acct_info_list="/ssproxy/queryAcctInfoList"
reg_mer_busi_info="/ssproxy/regMerBusiInfo"
modify_mer_busi_info="/ssproxy/modifyMerBusiInfo"
query_apply_status="/ssproxy/queryApplyStatus"
mer_file_upload="/ssproxy/file/upload"
add_mer_split_config="/ssproxy/addMerSplitConfig"
query_mer_split_config="/ssproxy/queryMerSplitConfig"
config_fq_mer_free="/ssproxy/configFqMerFee"
query_fq_mer_free_detail="/ssproxy/queryFqMerFeeDetail"
reg_activities="/ssproxy/regActivities"